package com.example.controller.teacher;

import com.example.dto.TeacherDTO;
import com.example.entity.Teacher;
import com.example.result.Result;
import com.example.service.TeacherService;
import com.example.vo.TeacherVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

@RestController
@Slf4j
@Api(tags = "老师相关接口")
@RequestMapping("/teacher")
public class TeacherController {
    @Autowired
    private TeacherService teacherService;

    /**
     * 新增老师基本信息
     *
     * @param teacherDTO
     * @return
     */
    @PostMapping
    @ApiOperation(value = "新增老师基本信息")
    public Result saveTeacher(@RequestBody TeacherDTO teacherDTO) {
        log.info("新增老师基本信息:{}", teacherDTO.getName());
        teacherService.saveTeacher(teacherDTO);
        return Result.success();
    }

    @Transactional
    @PutMapping("/{id}")
    @ApiOperation(value = "根据id更新老师信息")
    public Result updateTeacher(@RequestBody TeacherDTO teacherDTO, @PathVariable Long id) {
        log.info("根据id修改老师信息，{}", id);
        teacherService.updateTeacher(teacherDTO,id);
        return Result.success();
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "根据id查询老师信息")
    public Result<TeacherVO> getById(@PathVariable Long id){
        log.info("查询老师详情：{}",id);
        TeacherVO TeacherVO=teacherService.getById(id);
        return Result.success(TeacherVO);
    }

    @DeleteMapping("/{id}")
    @ApiOperation(value = "根据id删除老师信息")
    public Result deleteById(@PathVariable Long id){
        log.info("根据id删除老师信息:{}",id);
        teacherService.deleteById(id);
        return Result.success();
    }
}
