package com.example.service.impl;

import com.example.constant.MessageConstant;
import com.example.context.BaseContext;
import com.example.dto.AwardsDTO;
import com.example.entity.Awards;
import com.example.entity.Teacher;
import com.example.exception.AwordsNotFoundException;
import com.example.mapper.AwardsMapper;
import com.example.mapper.TeacherMapper;
import com.example.service.AwardsService;
import com.example.vo.AwardsVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AwardsServiceImpl implements AwardsService {

    @Autowired
    private AwardsMapper awardsMapper;
    @Autowired
    private TeacherMapper teacherMapper;

    /**
     * 老师获奖上传
     *
     * @param awardsDTO
     */
    @Override
    public void uploadAwards(AwardsDTO awardsDTO) {
        Awards awards = new Awards();
        BeanUtils.copyProperties(awardsDTO, awards);
        Long id = BaseContext.getCurrentId();
        awards.setTeacherId(id);
        awardsMapper.uploadAwards(awards);
        awardsMapper.addAwardsNum(id);

    }

    /**
     * 老师奖项修改
     *
     * @param awardsDTO
     * @param id
     */
    @Override
    public void updateAwards(AwardsDTO awardsDTO, Long id) {
        Awards awards = new Awards();
        BeanUtils.copyProperties(awardsDTO, awards);
        awards.setId(id);
        awardsMapper.updateAwards(awards);
    }

    /**
     * 获取指定奖项详细信息
     *
     * @param id
     * @return
     */
    @Override
    public AwardsVO getById(Long id) {

        AwardsVO awardsVO = new AwardsVO();
        Awards awards = awardsMapper.getById(id);
        if(awards == null){
            throw new AwordsNotFoundException(MessageConstant.AWORDS_NOT_FOUND);
        }
        BeanUtils.copyProperties(awards,awardsVO);
        return awardsVO;
    }

    /**
     * 删除指定奖项
     *
     * @param id
     */
    @Override
    public void deleteById(Long id) {
        awardsMapper.deleteById(id);
    }

}
